@@ -76,8 +76,7 @@ def mirror(x, tau):
 
 
 class Drawer():
-    """Drawer is used to aggregate a collection of images corresponding to a Polarization Calibration Sequence and
-    distribute a Set of Calibration Curves (SoCC) from those images.
+    """Drawer is used to aggregate a collection of images corresponding to a Polarization Calibration Sequence and distribute a Set of Calibration Curves (SoCC) from those images.
 
     Aggregation is achieved by simply loading all FITS files in a directory and reading the configuration of the
     Calibration Unit from header values. These values are formed into Calibration Sequence (CS) vectors that can be
@@ -91,75 +90,25 @@ class Drawer():
 
     Finally, multiple instances of Drawer can be concatenated simply with the + operator.
 
-    Attributes
-    (only those you might need)
-    ----------
-    instrument : str
-        The name of the instrument used to take the data (upper case)
-
-    nummod : int
-        The total number of modulator states in each step
-
-    numsteps : int
-        The total number of steps in the CS
-
-    shape : tuple
-        The shape of a single data exposure
-
-    theta_pol_steps : numpy.ndarray
-        The polarizer angle at each step in the CS
-
-    theta_ret_steps : numpy.ndarray
-        The retarder angle at each step in the CS
-
-    pol_in : numpy.ndarray
-        Boolean array - was the polarizer in the beam at each step?
-
-    ret_in : numpy.ndarray
-        Boolean array - was the retarder in the beam at each step?
-
-    timeobs : numpy.ndarray
-        The DATE-OBS keyword for each step of the CS. Format is MJD
-
-    date_bgn : float
-        Time at the start of the CS. Format is MJD
-
-    date_end : float
-        Time at the end of the CS. Format is MJD
-
-    wavelength : float
-        Coarse wavelength band of observations (nm)
-
-    azimuth : numpy.ndarray
-        Telescope azimuth at each step in the CS
-
-    elevation : numpy.ndarray
-        Telescope elevation at each step in the CS
-
-    table_angle : numpy.ndarray
-        Coude table angle at each step in the CS
-
-    I_clear : float
-        Average of the means of any detected Clear CS steps. Useful for initializing I_sys fit value.
 
     Notes
     -----
-    An example:
+    An example::
 
-    # Load the data from 'visp_CS_dir'.
-    >>> DRWR = Drawer('visp_CS_dir')
+        # Load the data from 'visp_CS_dir'.
+        >>> DRWR = Drawer('visp_CS_dir')
 
-    # Look at the number of modulator states and number of CS steps
-    >>> DRWR.nummod
-    8
+        # Look at the number of modulator states and number of CS steps
+        >>> DRWR.nummod
+        8
 
-    >>> len(DRWR.theta_pol_steps)
-    20
+        >>> len(DRWR.theta_pol_steps)
+        20
 
-    # Grab the SoCC for the pixel at (10, 100, 0)
-    >>> I = DRWR[10, 100, 0]
-    >>> I.shape
-    (8, 20)
+        # Grab the SoCC for the pixel at (10, 100, 0)
+        >>> I = DRWR[10, 100, 0]
+        >>> I.shape
+        (8, 20)
 
     Data access is via astropy.io.fits and is therefore very memory-efficient.
     """
@@ -594,62 +543,15 @@ class Drawer():
         plt.close('all')
 
 class Dresser():
-    """Dresser is, quite simply, a collection of Drawer objects. It's primary function is to allow the
-    `FittingFramework` to not have to worry about how many Drawers the user has provided for, e.g., fitting the M36
-    group parameters.
+    """Dresser is a collection of Drawer objects.
+
+    It's primary function is to allow the`FittingFramework` to not have to worry about how many Drawers the user has
+    provided for, e.g., fitting the M36 group parameters.
 
     This class doesn't do much except keep track of the Drawers and concatenate a StoCCinG when a user asks for a
     specific location.
 
     Its attributes are basically the same as those of Drawer
-
-    Attributes
-    (only those you might need)
-    ----------
-    instrument : str
-        The name of the instrument used to take the data (upper case)
-
-    nummod : int
-        The total number of modulator states in each step
-
-    numsteps : int
-        The total number of steps in all CS's across all Drawers
-
-    shape : tuple
-        The shape of a single data exposure
-
-    theta_pol_steps : numpy.ndarray
-        The polarizer angle at each CS step
-
-    theta_ret_steps : numpy.ndarray
-        The retarder angle at each CS step
-
-    pol_in : numpy.ndarray
-        Boolean array - was the polarizer in the beam at each step?
-
-    ret_in : numpy.ndarray
-        Boolean array - was the retarder in the beam at each step?
-
-    date_bgn : float
-        Time at the start of the CS of the first Drawer. Format is MJD
-
-    date_end : float
-        Time at the end of the CS of the last Drawer. Format is MJD
-
-    wavelength : float
-        Coarse wavelength band of observations (nm)
-
-    azimuth : numpy.ndarray
-        Telescope azimuth at each CS step
-
-    elevation : numpy.ndarray
-        Telescope elevation at each CS step
-
-    table_angle : numpy.ndarray
-        Coude table angle at each CS step
-
-    I_clear : float
-        Average of the means of any detected Clear CS steps. Useful for initializing I_sys fit value.
     """
 
     def __init__(self):
@@ -798,9 +700,11 @@ class Dresser():
         return data, uncertainty
 
 class CUModelParams():
-    """A container for CU Model parameters. The primary functions of this object are to write a FITS file that contains
-    these parameters in a format that allows Instrument Partners to resample them to whatever field they need and to
-    load a set of parameters after they have been resampled.
+    """A container for CU Model fit parameters.
+
+    The primary functions of this object are to write a FITS file that contains these parameters in a format that
+    allows Instrument Partners to resample them to whatever field they need and to load a set of parameters after they
+    have been resampled.
 
     The CU parameters are kept in a 3D array of shape (X, Y, L, Z) where (X, Y, L) is the shape of the FOV present in
     the Drawer(s) used in fitting and Z is the number of CU parameters (fixed and free).
@@ -1064,9 +968,11 @@ class CUModelParams():
         os.remove(self.tmp_name)
 
 class TelescopeModelParams():
-    """A container for Telescope Model parameters. The primary functions of this object are to write a FITS file that
-    contains these parameters in a format that allows Instrument Partners to resample them to whatever field they need
-    and to load a set of parameters after they have been resampled.
+    """A container for Telescope Model fit parameters.
+
+    The primary functions of this object are to write a FITS file that contains these parameters in a format that
+    allows Instrument Partners to resample them to whatever field they need and to load a set of parameters after
+    they have been resampled.
 
     The TM parameters are kept in a 3D array of shape (X, Y, L, 6) where (X, Y, L) is the shape of the FOV present in
     the StoCCinG used in fitting.
