@@ -74,6 +74,21 @@ class TestGenerateParameters(TestCase):
         self.assertEqual(d['U_in'], self.mode_opts['U_in']['value'])
         self.assertEqual(d['V_in'], self.mode_opts['V_in']['value'])
 
+    def test_use_M12_Q_fixed(self):
+        mode_opts = generic.init_fit_mode('use_M12', 666, False)
+        self.nummod = 10
+        TM = TelescopeModel.TelescopeModel([90],[0],[45])
+        TM.x34 = self.get_number_in_parameter_range('x34')
+        TM.t34 = self.get_number_in_parameter_range('t34')
+        TM.x56 = self.get_number_in_parameter_range('x56')
+        TM.t56 = self.get_number_in_parameter_range('t56')
+        CS = CUModel.CalibrationSequence(np.array([0]), np.array([0]), np.array([True]), np.array([True]),
+                                         np.array([False]),  np.array([57530]))
+
+        params = FittingFramework.generate_parameters([100], TM, CS, mode_opts, self.nummod, fit_TM=False)
+        self.assertTrue(params["Q_in"].value == 0)
+        self.assertTrue(params["Q_in"].vary == False)
+
     def test_TM_true(self):
 
         TM = TelescopeModel.TelescopeModel([90],[0],[45])
